# 🌐 `@geo watch`

watching [targets](./targets.yaml) through `@geo`.

```bash
 > @geo watch help
```

--include-- ./targets/chilcotin-river-landslide.md case study: Chilcotin River Landslide

## example run

```bash
@geo watch - \
    target=chilcotin-river-landslide to=aws_batch - -
```

🔥